@@ -55,9 +55,9 @@ class AliPay():
             if isinstance(value, dict):
                 complex_keys.append(key)
 
-        # 将字典类型的数据单独排序
+        # 将字典类型的数据dump出来
         for key in complex_keys:
-            data[key] = json.dumps(data[key], sort_keys=True).replace(" ", "")
+            data[key] = json.dumps(data[key], separators=(',', ':'))
 
         return sorted([(k, v) for k, v in data.items()])
 
